static String gv_nls_noint_de_dat [] = {
"GV*miscmenuLabel.label:			Extras: Menueeintraege",
"GV*x11devLabel.label:	Geraet",
"GV*scratchDirLabel.label:		Scratch Directory",
"GV*misc.label:				Extras",
"GV*miscMenu.stop.label:			Interpreter beenden",
"GV*miscMenu.save_all.label:		Alles speichern",
"GV*saveDirLabel.label:			Ordner zum Speichern",
"GV*infoPopup.title:			Ghostscript-Meldungen",
"GV*dirsLabel.label:			Dateiauswahlordner",
"GV*scanLabel.label:	Scan PDF",
"GV*optiongvPopup*magLabel.label:	Groesse",
"GV*button2.label:			Datei oeffnen",
"GV*optionsetupPopup.title:		Allg. Einstellungen",
"GV*optiongvPopup*respectDSC.label:	DSC beachten",
"GV*miscMenu.save_marked.label:		Markiertes speichern",
"GV*scrolling.label:			Umgekehrtes Scrollen",
"GV*optiongvPopup*forientLabel.label:	Rueckfall-Orientatierung",
"GV*button1.label:			Abbrechen",
"GV*filters.label:			Filter:",
"GV*confirmLabel.label:			Beenden bestaetigen",
"GV*printMarked.label:			Markiertes drucken",
"GV*optiongvPopup*orientLabel.label:	\\     Orientatierung    \\ ",
"GV*optiongvPopup*fmediaLabel.label:	Rueckfall-Papiergroesse",
"GV*confirmPopup*done.label:		Beenden",
"GV*optiongvPopup*autoResize.label:	Variable Groesse",
"GV*defaults.label:	Standardeinstellungen",
"GV*uncompressLabel.label:		Dekomprimieren",
"GV*miscMenu.unmark.label:		Demarkieren",
"GV*safer.label:		Safer",
"GV*saveMarked.label:			Markiertes speichern",
"GV*optiongvPopup*swapLandscape.label:	Swap Querformat",
"GV*miscMenu.update.label:		Datei neu laden",
"GV*miscMenu.print_marked.label:		Markiertes drucken",
"GV*scalesLabel.label:			Vergroesserung",
"GV*x11alphadevLabel.label:		Antialias",
"GV*saveAll.label:			Alles speichern",
"GV*miscMenu.toggle_current.label:	Aktuelle umschaltewn",
"GV*miscMenu.toggle_odd.label:		Gerade umschalten",
"GV*miscMenu.toggle_even.label:		Ungerade umschalten",
"GV*printCommandLabel.label:		Druckkommando",
"GV*updateFile.label:			Neu laden",
"GV*optiongsPopup.title:			Ghostscript Einstellungen",
"GV*quiet.label:		Quiet",
"GV*confirmPopup.title:			Bestaetigen",
"GV*mediasLabel.label:			Mediengroessen",
"GV*optionfsPopup.title:			Dateiauswahloptionen",
"GV*optiongvPopup*mediaLabel.label:	\\ Papiergroesse \\ ",
"GV*convLabel.label:	Konvertiere PDF",
"GV*zoomPopup.title:			Lupe",
"GV*optiongvPopup.title:			gv Einstellungen",
"GV*confirmPrint.label:			Drucken bestaetigen",
"GV*filterLabel.label:			Standard-Filter",
"GV*filtersLabel.label:			Dateiauswahlfilters",
"GV*checkFile.label:			Datei beobachten",
"GV*toggleOdd.label:",
"GV*optiongvPopup*scalesLabel.label:	\\   Vergroesserungen  \\ ",
"GV*toggleCurrent.label:",
"GV*dialogPopup*cancel.label:		Abbrechen",
"GV*fileSelPopup.title:			Datei oeffnen",
"GV*eyeGuide.label:			?Scrolling Eye Guide?",
"GV*magmenuLabel.label:			Mag Menu Entries",
"GV*rescan.label:			Ordner neu einlesen",
"GV*miscMenu.print_all.label:		Alles drucken",
"GV*gsLabel.label:	Interpreter",
"GV*optiongvPopup*antialias.label:	Antialias",
"GV*printAll.label:			Alles drucken ",
"GV*argumentsLabel.label:	Argumente",
"GV*toggleEven.label:",
"GV*scaleBaseLabel.label:		Vergroesserungsbasis",
"GV*screenSizeLabel.label:		Bildschiemgroesse (mm)",
"GV*dialogPopup.title:			Dialog",
"GV*unmarkAll.label:",
"GV*autoCenter.label:			Automatisch zentrieren",
"GV*redisplay.label:			Neu laden",
"GV*confirmPopup*cancel.label:		Abbrechen",
"GV*openFile.label:			Oeffnen",
"GV*save.label:				Speichern",
"GV*notePopup.title:			Nachricht",
"GV*optiongvPopup*eof.label:		EOF ignorieren",
"GV*apply.label:				Anwenden",
"GV*miscMenu.redisplay.label:		Neu laden",
"GV*dirs.label:				Ordner",
"GV*notePopup*done.label:		OK",
"GV*copyright.Label:			Copyright",
"GV*optionsgv.Label:			gv Einstellungen ...",
"GV*mark.Label:				Markieren",
"GV*dismiss.Label:			Abbrechen",
"GV*center.Label:			Zentrieren",
"GV*printMarkedPages.Label:		Drucke markierte ...",
"GV*update.Label:			Neu laden",
"GV*optionsgs.Label:			Ghostscript Einstellungen ...",
"GV*presentation.Label:			Presentationsmodus",
"GV*saveAllPages.Label:			Speichere Dokument ...",
"GV*pageButton*unmark.Label:		Alle demarkieren",
"GV*automatic.Label:			Automatik",
"GV*unmark.Label:			Demarkieren",
"GV*reopen.Label:			Neu laden",
"GV*dsc.Label:				Beachte Documentstruktur",
"GV*pixmap.Label:			?Backing Pixmap?",
"GV*savepos.Label:			Savepos",
"GV*pageButton.Label:			Seite",
"GV*open.Label:				Oeffnen...",
"GV*fileButton.Label:			Datei",
"GV*antialias.Label:			Antialias",
"GV*show.Label:				Neu anzeigen",
"GV*stateButton.Label:			Status",
"GV*pageButton*current.Label:		Aktuelle Markierung wechselnn",
"GV*optionssetup.Label:			Allg. Einstellungen ...",
"GV*ascaleLabel.Label:			Beliebige Vergroesserung",
"GV*next.Label:				Naechste",
"GV*seascape.Label:			Alt. Querformat",
"GV*cancel.Label:			Abbrechen",
"GV*watch.Label:				Datei beobachten",
"GV*titleLabel.Label:			Titel anzeigen",
"GV*processButton.Label:			\\ processing",
"GV*stop.Label:				Interpreter beenden",
"GV*upsidedown.Label:			Umgedreht",
"GV*pageButton*even.Label:		Gerade Markierungen wechseln",
"GV*quit.Label:				Beenden",
"GV*nextPage.Label:			>>",
"GV*eof.Label:				EOF Kommenatre ignorieren",
"GV*landscape.Label:			Querformat",
"GV*printAllPages.Label:			Dokument drucken ...",
"GV*infoVerboseLabel.Label:			Info.Popup",
"GV*size.Label:				Automatische Groesse",
"GV*prevPage.Label:			<<",
"GV*prev.Label:				Vorherige",
"GV*saveMarkedPages.Label:		Markierte Seiten speichern ...",
"GV*pageButton*odd.Label:		Ungerade Markierungen wechseln",
"GV*optionsfs.Label:			Dateiauswahloptionen ...",
"GV*swap.Label:				Querformat umschalten",
"GV*portrait.Label:			Hochformat",
"GV*watchFile.Label:			Datei beobachten",
"GV*gs.errors.none.Label:		Keine",
"GV*gs.errors.all.Label:			Alle",
"GV*gs.errors.errors.Label:		Fehler",
"GV.scales:		Natuerliche Groesse,	1.000,	screen	\\n\
			Pixelbasiert,	1.000,	pixel	\\n\
			Beliebige Vergroesserung,	-2		\\n\
			Hoehe anpassen,	-3		\\n\
			Breite anpassen,	-1		\\n\
			Beides anpassen,	0.000		\\n\
			0.100,		0.100		\\n\
			0.125,		0.125		\\n\
			0.250,		0.250		\\n\
			0.500,		0.500		\\n\
			0.707,		0.707		\\n\
			1.000,		1.000		\\n\
			1.414,		1.414		\\n\
			2.000,		2.000		\\n\
			4.000,		4.000		\\n\
			8.000,		8.000		\\n\
			10.00,		10.00",
"GV*quitstyle.never.Label:		Niemals",
"GV*quitstyle.always.Label:		Immer",
"GV*quitstyle.whenprocessing.Label:	Bei Verarbeitung",
"GV*title.filename.Label:		Dateiname",
"GV*title.notitle.Label:			Kein Titel",
"GV*title.documenttitle.Label:		Dokumenttitel",
"GV*strings.saveMarkedPages:		Markiere Seiten speichern",
"GV*strings.saveCurrentPage:		Aktuelle Seite speichern",
"GV*strings.saveDocument:		Dokument speichern",
"GV*strings.saveAsPDF:			Als PDF speichern",
"GV*strings.openFile:			Datei oeffnen",
"GV*strings.passwordPrompt:		Passwort:",
"GV*strings.passwordRequired:		Passwort erforderlich",
"GV*strings.quitConfirm:			Wollen Sie wirklich GNU gv beenden?",
"GV*strings.putTexCommand:		Schreibe eine TeX-Anweisung an die aktuelle Position",
"GV*strings.texCommand:			TeX -Anweisung",
"GV.version:		gv 3.6.7.90",
"GV*strings.stillInProgress:		Noch in Bearbeitung:",
"GV*strings.execOfFailed:		Ausfuehrung von %s fehlgeschlagen",
"GV*strings.copyrightTranslation:	Markus Steinborn <gnugv_maintainer@yahoo.de>",
0};

static String gv_nls_ko_KR_UTF_8_dat [] = {
"GV*zoomPopup.title:			GV - 확대",
"GV*infoPopup.title:			고스트 스크립트 메시지",
"GV*dialogPopup.title:			다이알로그",
"GV*notePopup.title:			메시지",
"GV*confirmPopup.title:			확인",
"GV*optionfsPopup.title:			파일 선택 옵션",
"GV*optiongsPopup.title:			고스트 스크립트 옵션",
"GV*optiongvPopup.title:			GV 옵션",
"GV*optionsetupPopup.title:		설정 옵션",
"GV*fileSelPopup.title:			파일 열기",
"GV*cancel.Label:			취소",
"GV*dismiss.Label:			닫기",
"GV*apply.label:				적용",
"GV*copyright.Label:			저작권",
"GV*quit.Label:				종료",
"GV*fileButton.Label:			파일",
"GV*open.Label:				열기 ...",
"GV*reopen.Label:			재열기",
"GV*update.Label:			경신",
"GV*printAllPages.Label:			문서 인쇄 ...",
"GV*printMarkedPages.Label:		마크한 페이지 인쇄 ...",
"GV*saveAllPages.Label:			문서 저장 ...",
"GV*saveMarkedPages.Label:		마크한 페이지 저장 ...",
"GV*stateButton.Label:			환경 설정",
"GV*stop.Label:				중지",
"GV*dsc.Label:				문서 구조화",
"GV*eof.Label:				EOF 주석 무시",
"GV*antialias.Label:			매끄러운 화면 처리",
"GV*watchFile.Label:			자동 파일경신",
"GV*showTitle.Label:			타이틀 표시",
"GV*pixmap.Label:			Backing Pixmap",
"GV*size.Label:				자동 크기 조절",
"GV*watch.Label:				자동 파일경신",
"GV*optionsgv.Label:			GV 옵션 ...",
"GV*optionsfs.Label:			파일 선택 옵션 ...",
"GV*optionsgs.Label:			고스트 스크립트 옵션 ...",
"GV*optionssetup.Label:			설정 옵션 ...",
"GV*pageButton.Label:			페이지",
"GV*next.Label:				다음",
"GV*show.Label:				화면 재시작",
"GV*prev.Label:				이전",
"GV*center.Label:			중간",
"GV*pageButton*current.Label:		현재페이지 마크/해제",
"GV*pageButton*even.Label:		짝수페이지 마크/해제",
"GV*pageButton*odd.Label:		홀수페이지 마크/해제",
"GV*pageButton*unmark.Label:		전 마크 해제",
"GV*processButton.Label:			\\ 진행중",
"GV*mark.Label:				마크",
"GV*prevPage.Label:			<<",
"GV*nextPage.Label:			>>",
"GV*unmark.Label:			표시 안함",
"GV*automatic.Label:			자동",
"GV*portrait.Label:			Portrait",
"GV*landscape.Label:			Landscape",
"GV*upsidedown.Label:			상하 반전",
"GV*seascape.Label:			Seascape",
"GV*swap.Label:				Landscape변환",
"GV*toggleCurrent.label:			현재페이지 마크/해제",
"GV*toggleEven.label:			짝수페이지 마크/해제",
"GV*toggleOdd.label:			홀수페이지 마크/해제",
"GV*unmarkAll.label:			모두 표시 안함",
"GV*printAll.label:			모두 인쇄",
"GV*printMarked.label:			마크부분 인쇄",
"GV*saveAll.label:			모두 저장",
"GV*saveMarked.label:			표시 저장",
"GV*openFile.label:			열기",
"GV*redisplay.label:			화면 재시작",
"GV*updateFile.label:			파일경신",
"GV*checkFile.label:			파일 확인",
"GV*filters.label:			필터",
"GV*dirs.label:				디렉토리",
"GV*button1.label:			취소",
"GV*button2.label:			파일 열기",
"GV*rescan.label:			디렉토리 검색",
"GV*screenSizeLabel.label:		회면 사이즈mm]",
"GV*versionPopup*versionDone*label:	취소",
"GV*dialogPopup*cancel.label:		취소",
"GV*notePopup*done.label:		예",
"GV*confirmPopup*cancel.label:		취소",
"GV*confirmPopup*done.label:		종료",
"GV*save.label:				저장",
"GV*optiongvPopup*mediaLabel.label:	\\ 용지 사이즈 \\ ",
"GV*optiongvPopup*fmediaLabel.label:	불판명시의 용지 사이즈",
"GV*optiongvPopup*orientLabel.label:	\\ 원 상태 \\ ",
"GV*optiongvPopup*forientLabel.label:	윈 상태로 복귀",
"GV*optiongvPopup*magLabel.label:	확대축소",
"GV*optiongvPopup*antialias.label:	다듬기",
"GV*optiongvPopup*respectDSC.label:	DSC를 유효",
"GV*optiongvPopup*eof.label:		EOF를 무시",
"GV*optiongvPopup*autoResize.label:	가변 사이즈",
"GV*optiongvPopup*swapLandscape.label:	Landscape변환",
"GV*optiongvPopup*scalesLabel.label:	\\   스케일 \\ ",
"GV*miscmenuLabel.label:			기타 메뉴",
"GV*magmenuLabel.label:			확대 메뉴 목록",
"GV*mediasLabel.label:			미디어 크기",
"GV*confirmLabel.label:			확인 종료",
"GV*misc.label:				기타",
"GV*scrolling.label:			스크롤 반전",
"GV*eyeGuide.label:			스크롤 가이드",
"GV*confirmPrint.label:			인쇄시 확인",
"GV*uncompressLabel.label:		압축 전개",
"GV*autoCenter.label:			자동적으로 중앙으로",
"GV*printCommandLabel.label:		인쇄 명령어",
"GV*scratchDirLabel.label:		스크레치 디렉토리",
"GV*saveDirLabel.label:			디렉토리 저장",
"GV*scalesLabel.label:			스케일",
"GV*scaleBaseLabel.label:		기본 스케일",
"GV*safer.label:				보다 안전하게",
"GV*quiet.label:				종료",
"GV*defaults.label:			시스템 표준값",
"GV*scanLabel.label:			PDF 검색",
"GV*convLabel.label:			PDF 변환",
"GV*gsLabel.label:			Postscript인터럽트",
"GV*x11devLabel.label:			디바이스",
"GV*x11alphadevLabel.label:		디바이스 조정",
"GV*argumentsLabel.label:		인수",
"GV*filtersLabel.label:			파일 선택 필터",
"GV*dirsLabel.label:			파일 선택 디렉토리",
"GV*filterLabel.label:			기본 필터",
"GV*miscMenu.update.label:		파일경신",
"GV*miscMenu.redisplay.label:		화면 재조정",
"GV*miscMenu.stop.label:			인터럽트 중지",
"GV*miscMenu.toggle_current.label:	현재페이지 마크/해제",
"GV*miscMenu.toggle_odd.label:		홀수페이지 마크/해제",
"GV*miscMenu.toggle_even.label:		짝수페이지 마크/해제",
"GV*miscMenu.unmark.label:		모두 표시 안함",
"GV*miscMenu.print_all.label:		모두 인쇄",
"GV*miscMenu.print_marked.label:		마크 부분 인쇄",
"GV*miscMenu.save_all.label:		모두 저장",
"GV*miscMenu.save_marked.label:		표시 저장",
0};

static String gv_nls_ja_JP_UTF_8_dat [] = {
"GV*zoomPopup.title:			GV - 拡大画面",
"GV*infoPopup.title:			GhostScriptメッセージ",
"GV*dialogPopup.title:			ダイアログ",
"GV*notePopup.title:			メッセージ",
"GV*confirmPopup.title:			確認",
"GV*optionfsPopup.title:			ファイル選択オプション",
"GV*optiongsPopup.title:			Ghostscriptオプション",
"GV*optiongvPopup.title:			GVオプション",
"GV*optionsetupPopup.title:		セットアップオプション",
"GV*fileSelPopup.title:			ファイルを開く",
"GV*cancel.Label:			キャンセル",
"GV*dismiss.Label:			閉じる",
"GV*apply.label:				適用",
"GV*copyright.Label:			著作権",
"GV*quit.Label:				終了",
"GV*fileButton.Label:			ファイル",
"GV*open.Label:				開く ...",
"GV*reopen.Label:			再オープン",
"GV*update.Label:			更新",
"GV*printAllPages.Label:			文章印刷 ...",
"GV*printMarkedPages.Label:		マークしたページの印刷...",
"GV*saveAllPages.Label:			文章保存 ...",
"GV*saveMarkedPages.Label:		マークしたページの保存...",
"GV*stateButton.Label:			環境設定",
"GV*stop.Label:				割り込み停止",
"GV*dsc.Label:				文書構造によるスペクト調整",
"GV*eof.Label:				EOFコメントを無視",
"GV*antialias.Label:			アンチエイリアス",
"GV*watchFile.Label:			自動ファイル更新",
"GV*showTitle.Label:			タイトル表示",
"GV*pixmap.Label:			Backing Pixmap",
"GV*size.Label:				自動サイズ変更",
"GV*watch.Label:				自動ファイル更新",
"GV*optionsgv.Label:			GVオプション...",
"GV*optionsfs.Label:			ファイル選択オプション...",
"GV*optionsgs.Label:			Ghostscriptオプション...",
"GV*optionssetup.Label:			セットアップオプション...",
"GV*pageButton.Label:			ページ",
"GV*next.Label:				次へ",
"GV*show.Label:				再表示",
"GV*prev.Label:				前へ",
"GV*center.Label:			中央",
"GV*pageButton*current.Label:		現在のページをマーク/解除",
"GV*pageButton*even.Label:		偶数ページをマーク/解除",
"GV*pageButton*odd.Label:		奇数ページをマーク/解除",
"GV*pageButton*unmark.Label:		全マーク解除",
"GV*processButton.Label:			\\ 実行",
"GV*mark.Label:				マーク",
"GV*prevPage.Label:			<<",
"GV*nextPage.Label:			>>",
"GV*unmark.Label:			マーク解除",
"GV*automatic.Label:			自動",
"GV*portrait.Label:			ポートレート",
"GV*landscape.Label:			ランドスケープ",
"GV*upsidedown.Label:			上下反転",
"GV*seascape.Label:			逆ランドスケープ",
"GV*swap.Label:				ランドスケープ変換",
"GV*toggleCurrent.label:			現在のページマーク/解除",
"GV*toggleEven.label:			偶数ページマーク/解除",
"GV*toggleOdd.label:			奇数ページマーク/解除",
"GV*unmarkAll.label:			全マーク解除",
"GV*printAll.label:			全印刷",
"GV*printMarked.label:			マーク部分印刷",
"GV*saveAll.label:			全保存",
"GV*saveMarked.label:			マーク部分保存",
"GV*openFile.label:			開く",
"GV*redisplay.label:			再表示",
"GV*updateFile.label:			ファイル更新",
"GV*checkFile.label:			ファイルチェック",
"GV*filters.label:			フィルタ:",
"GV*dirs.label:				ディレクトリ",
"GV*button1.label:			キャンセル",
"GV*button2.label:			ファイルを開く",
"GV*rescan.label:			ディレクトリ再読込",
"GV*screenSizeLabel.label:		画面サイズ[mm]",
"GV*versionPopup*versionDone*label:	閉じる",
"GV*dialogPopup*cancel.label:		キャンセル",
"GV*notePopup*done.label:		了解",
"GV*confirmPopup*cancel.label:		キャンセル",
"GV*confirmPopup*done.label:		終了",
"GV*save.label:				保存",
"GV*optiongvPopup*mediaLabel.label:	\\ 用紙サイズ \\ ",
"GV*optiongvPopup*fmediaLabel.label:	判別不明時の用紙サイズ",
"GV*optiongvPopup*orientLabel.label:	\\ 用紙の向き \\ ",
"GV*optiongvPopup*forientLabel.label:	判別不明時の用紙向き",
"GV*optiongvPopup*magLabel.label:	拡大縮小",
"GV*optiongvPopup*antialias.label:	アンチエイリアス",
"GV*optiongvPopup*respectDSC.label:	DSCを有効",
"GV*optiongvPopup*eof.label:		EOFを無視",
"GV*optiongvPopup*autoResize.label:	可変サイズ",
"GV*optiongvPopup*swapLandscape.label:	ランドスケープ変換",
"GV*optiongvPopup*scalesLabel.label:	\\   スケール  \\ ",
"GV*miscmenuLabel.label:			その他メニューエントリ",
"GV*magmenuLabel.label:			拡大メニューエントリ",
"GV*mediasLabel.label:			メディアの大きさ",
"GV*confirmLabel.label:			終了時の確認",
"GV*misc.label:				その他",
"GV*scrolling.label:			スクロール反転",
"GV*eyeGuide.label:			スクロールガイド",
"GV*confirmPrint.label:			印刷時の確認",
"GV*uncompressLabel.label:		圧縮展開",
"GV*autoCenter.label:			自動的に中央へ",
"GV*printCommandLabel.label:		印刷コマンド",
"GV*scratchDirLabel.label:		スクラッチディレクトリ",
"GV*saveDirLabel.label:			保存ディレクトリ",
"GV*scalesLabel.label:			スケール",
"GV*scaleBaseLabel.label:		スケールベース",
"GV*safer.label:				より安全に",
"GV*quiet.label:				終了",
"GV*defaults.label:			システム標準値",
"GV*scanLabel.label:			PDF読み込み",
"GV*convLabel.label:			PDF変換",
"GV*gsLabel.label:			Postscriptエンジン",
"GV*x11devLabel.label:			デバイス",
"GV*x11alphadevLabel.label:		アンチエイリアスデバイス",
"GV*argumentsLabel.label:		引数",
"GV*filtersLabel.label:			ファイル選択フィルタ",
"GV*dirsLabel.label:			ファイル選択ディレクトリ",
"GV*filterLabel.label:			標準フィルタ",
"GV*miscMenu.update.label:		ファイル更新",
"GV*miscMenu.redisplay.label:		再表示",
"GV*miscMenu.stop.label:			割り込み停止",
"GV*miscMenu.toggle_current.label:	現在のページマーク/解除",
"GV*miscMenu.toggle_odd.label:		奇数ページマーク/解除",
"GV*miscMenu.toggle_even.label:		偶数ページマーク/解除",
"GV*miscMenu.unmark.label:		全マーク解除",
"GV*miscMenu.print_all.label:		全印刷",
"GV*miscMenu.print_marked.label:		マーク部分印刷",
"GV*miscMenu.save_all.label:		全保存",
"GV*miscMenu.save_marked.label:		マーク部分保存",
0};

static String gv_nls_de_UTF_8_dat [] = {
"GV*miscmenuLabel.label:			Extras: Menüeinträge",
"GV*x11devLabel.label:	Gerät",
"GV*scratchDirLabel.label:		Scratch Directory",
"GV*misc.label:				Extras",
"GV*miscMenu.stop.label:			Interpreter beenden",
"GV*miscMenu.save_all.label:		Alles speichern",
"GV*saveDirLabel.label:			Ordner zum Speichern",
"GV*infoPopup.title:			Ghostscript-Meldungen",
"GV*dirsLabel.label:			Dateiauswahlordner",
"GV*scanLabel.label:	Scan PDF",
"GV*optiongvPopup*magLabel.label:	Größe",
"GV*button2.label:			Datei öffnen",
"GV*optionsetupPopup.title:		Allg. Einstellungen",
"GV*optiongvPopup*respectDSC.label:	DSC beachten",
"GV*miscMenu.save_marked.label:		Markiertes speichern",
"GV*scrolling.label:			Umgekehrtes Scrollen",
"GV*optiongvPopup*forientLabel.label:	Rückfall-Orientatierung",
"GV*button1.label:			Abbrechen",
"GV*filters.label:			Filter:",
"GV*confirmLabel.label:			Beenden bestätigen",
"GV*printMarked.label:			Markiertes drucken",
"GV*optiongvPopup*orientLabel.label:	\\     Orientatierung    \\ ",
"GV*optiongvPopup*fmediaLabel.label:	Rückfall-Papiergröße",
"GV*confirmPopup*done.label:		Beenden",
"GV*optiongvPopup*autoResize.label:	Variable Größe",
"GV*defaults.label:	Standardeinstellungen",
"GV*uncompressLabel.label:		Dekomprimieren",
"GV*miscMenu.unmark.label:		Demarkieren",
"GV*safer.label:		Safer",
"GV*saveMarked.label:			Markiertes speichern",
"GV*optiongvPopup*swapLandscape.label:	Swap Qürformat",
"GV*miscMenu.update.label:		Datei neu laden",
"GV*miscMenu.print_marked.label:		Markiertes drucken",
"GV*scalesLabel.label:			Vergrößerung",
"GV*x11alphadevLabel.label:		Antialias",
"GV*saveAll.label:			Alles speichern",
"GV*miscMenu.toggle_current.label:	Aktülle umschaltewn",
"GV*miscMenu.toggle_odd.label:		Gerade umschalten",
"GV*miscMenu.toggle_even.label:		Ungerade umschalten",
"GV*printCommandLabel.label:		Druckkommando",
"GV*updateFile.label:			Neu laden",
"GV*optiongsPopup.title:			Ghostscript Einstellungen",
"GV*quiet.label:		Quiet",
"GV*confirmPopup.title:			Bestätigen",
"GV*mediasLabel.label:			Mediengrößen",
"GV*optionfsPopup.title:			Dateiauswahloptionen",
"GV*optiongvPopup*mediaLabel.label:	\\ Papiergröße \\ ",
"GV*convLabel.label:	Konvertiere PDF",
"GV*zoomPopup.title:			Lupe",
"GV*optiongvPopup.title:			gv Einstellungen",
"GV*confirmPrint.label:			Drucken bestätigen",
"GV*filterLabel.label:			Standard-Filter",
"GV*filtersLabel.label:			Dateiauswahlfilters",
"GV*checkFile.label:			Datei beobachten",
"GV*toggleOdd.label:",
"GV*optiongvPopup*scalesLabel.label:	\\   Vergrösßrungen  \\ ",
"GV*toggleCurrent.label:",
"GV*dialogPopup*cancel.label:		Abbrechen",
"GV*fileSelPopup.title:			Datei öffnen",
"GV*eyeGuide.label:			?Scrolling Eye Guide?",
"GV*magmenuLabel.label:			Mag Menu Entries",
"GV*rescan.label:			Ordner neu einlesen",
"GV*miscMenu.print_all.label:		Alles drucken",
"GV*gsLabel.label:	Interpreter",
"GV*optiongvPopup*antialias.label:	Antialias",
"GV*printAll.label:			Alles drucken ",
"GV*argumentsLabel.label:	Argumente",
"GV*toggleEven.label:",
"GV*scaleBaseLabel.label:		Vergrößerungsbasis",
"GV*screenSizeLabel.label:		Bildschiemgröße (mm)",
"GV*dialogPopup.title:			Dialog",
"GV*unmarkAll.label:",
"GV*autoCenter.label:			Automatisch zentrieren",
"GV*redisplay.label:			Neu laden",
"GV*confirmPopup*cancel.label:		Abbrechen",
"GV*openFile.label:			Öffnen",
"GV*save.label:				Speichern",
"GV*notePopup.title:			Nachricht",
"GV*optiongvPopup*eof.label:		EOF ignorieren",
"GV*apply.label:				Anwenden",
"GV*miscMenu.redisplay.label:		Neu laden",
"GV*dirs.label:				Ordner",
"GV*notePopup*done.label:		OK",
"GV*copyright.Label:			Copyright",
"GV*optionsgv.Label:			gv Einstellungen ...",
"GV*mark.Label:				Markieren",
"GV*dismiss.Label:			Abbrechen",
"GV*center.Label:			Zentrieren",
"GV*printMarkedPages.Label:		Drucke markierte ...",
"GV*update.Label:			Neu laden",
"GV*optionsgs.Label:			Ghostscript Einstellungen ...",
"GV*presentation.Label:			Presentationsmodus",
"GV*saveAllPages.Label:			Speichere Dokument ...",
"GV*pageButton*unmark.Label:		Alle demarkieren",
"GV*automatic.Label:			Automatik",
"GV*unmark.Label:			Demarkieren",
"GV*reopen.Label:			Neu laden",
"GV*dsc.Label:				Beachte Documentstruktur",
"GV*pixmap.Label:			?Backing Pixmap?",
"GV*savepos.Label:			Savepos",
"GV*pageButton.Label:			Seite",
"GV*open.Label:				Öffnen...",
"GV*fileButton.Label:			Datei",
"GV*antialias.Label:			Antialias",
"GV*show.Label:				Neu anzeigen",
"GV*stateButton.Label:			Status",
"GV*pageButton*current.Label:		Aktülle Markierung wechselnn",
"GV*optionssetup.Label:			Allg. Einstellungen ...",
"GV*ascaleLabel.Label:			Beliebige Vergrößerung",
"GV*next.Label:				Nächste",
"GV*seascape.Label:			Alt. Qürformat",
"GV*cancel.Label:			Abbrechen",
"GV*watch.Label:				Datei beobachten",
"GV*titleLabel.Label:			Titel anzeigen",
"GV*processButton.Label:			\\ processing",
"GV*stop.Label:				Interpreter beenden",
"GV*upsidedown.Label:			Umgedreht",
"GV*pageButton*even.Label:		Gerade Markierungen wechseln",
"GV*quit.Label:				Beenden",
"GV*nextPage.Label:			>>",
"GV*eof.Label:				EOF Kommenatre ignorieren",
"GV*landscape.Label:			Qürformat",
"GV*printAllPages.Label:			Dokument drucken ...",
"GV*infoVerboseLabel.Label:			Info.Popup",
"GV*size.Label:				Automatische Größe",
"GV*prevPage.Label:			<<",
"GV*prev.Label:				Vorherige",
"GV*saveMarkedPages.Label:		Markierte Seiten speichern ...",
"GV*pageButton*odd.Label:		Ungerade Markierungen wechseln",
"GV*optionsfs.Label:			Dateiauswahloptionen ...",
"GV*swap.Label:				Qürformat umschalten",
"GV*portrait.Label:			Hochformat",
"GV*watchFile.Label:			Datei beobachten",
"GV*gs.errors.none.Label:		Keine",
"GV*gs.errors.all.Label:			Alle",
"GV*gs.errors.errors.Label:		Fehler",
"GV.scales:		Natürliche Größe,	1.000,	screen	\\n\
			Pixelbasiert,	1.000,	pixel	\\n\
			Beliebige Vergrößerung,	-2		\\n\
			Höhe anpassen,	-3		\\n\
			Breite anpassen,	-1		\\n\
			Beides anpassen,	0.000		\\n\
			0.100,		0.100		\\n\
			0.125,		0.125		\\n\
			0.250,		0.250		\\n\
			0.500,		0.500		\\n\
			0.707,		0.707		\\n\
			1.000,		1.000		\\n\
			1.414,		1.414		\\n\
			2.000,		2.000		\\n\
			4.000,		4.000		\\n\
			8.000,		8.000		\\n\
			10.00,		10.00",
"GV*quitstyle.never.Label:		Niemals",
"GV*quitstyle.always.Label:		Immer",
"GV*quitstyle.whenprocessing.Label:	Bei Verarbeitung",
"GV*title.filename.Label:		Dateiname",
"GV*title.notitle.Label:			Kein Titel",
"GV*title.documenttitle.Label:		Dokumenttitel",
"GV*strings.saveMarkedPages:		Markiere Seiten speichern",
"GV*strings.saveCurrentPage:		Aktülle Seite speichern",
"GV*strings.saveDocument:		Dokument speichern",
"GV*strings.saveAsPDF:			Als PDF speichern",
"GV*strings.openFile:			Datei öffnen",
"GV*strings.passwordPrompt:		Passwort:",
"GV*strings.passwordRequired:		Passwort erforderlich",
"GV*strings.quitConfirm:			Wollen Sie wirklich GNU gv beenden?",
"GV*strings.putTexCommand:		Schreibe eine TeX-Anweisung an die aktülle Position",
"GV*strings.texCommand:			TeX -Anweisung",
"GV.version:		gv 3.6.7.90",
"GV*strings.stillInProgress:		Noch in Bearbeitung:",
"GV*strings.execOfFailed:		Ausführung von %s fehlgeschlagen",
"GV*strings.copyrightTranslation:	Markus Steinborn <gnugv_maintainer@yahoo.de>",
0};

String* getI18N(char* locale)
{
   if (!strcmp(locale, "noint:de")) return gv_nls_noint_de_dat;
   if (!strcmp(locale, "ko_KR.UTF-8")) return gv_nls_ko_KR_UTF_8_dat;
   if (!strcmp(locale, "ja_JP.UTF-8")) return gv_nls_ja_JP_UTF_8_dat;
   if (!strcmp(locale, "de.UTF-8")) return gv_nls_de_UTF_8_dat;
   return 0;
}
